@@ -32,13 +32,14 @@ class BaseSearchCV(metaclass=ABCMeta):
             Defaults to 0.
         kwargs (Any): Keyword arguments for the model_fn function.
     """
+
     @abstractmethod
     def __init__(
         self,
         model_fn: Callable[..., tf.keras.models.Model],
         n_folds: int = 3,
         verbose: int = 0,
-        **kwargs: Any
+        **kwargs: Any,
     ) -> None:
         self.model_fn = model_fn
         self.verbose = verbose
@@ -55,7 +56,7 @@ class BaseSearchCV(metaclass=ABCMeta):
         self,
         dataset: tf.data.Dataset,
         parameter_obj: Union[ParameterGrid, ParameterSampler],
-        **kwargs: Any
+        **kwargs: Any,
     ) -> None:
         """Runs the exhaustive grid search over the parameter grid.
 
@@ -78,7 +79,7 @@ class BaseSearchCV(metaclass=ABCMeta):
         if tensorboard_callback:
             tensorboard_log_dir = tensorboard_callback.log_dir
 
-        split_fraction = (1 / self.n_folds)
+        split_fraction = 1 / self.n_folds
 
         tf_log_level = logger.level
         logger.setLevel(logging.ERROR)  # Issue 30: Ignore warnings for training
@@ -94,40 +95,28 @@ class BaseSearchCV(metaclass=ABCMeta):
                     print(f"Running Fold: {fold}")
 
                 model = self.model_fn(
-                    **grid_combination,
-                    **self.model_fn_kwargs
+                    **grid_combination, **self.model_fn_kwargs
                 )
 
                 train_dataset, val_dataset = dataset_split(
-                    dataset=dataset,
-                    split_fraction=split_fraction,
-                    fold=fold
+                    dataset=dataset, split_fraction=split_fraction, fold=fold
                 )
 
                 if tensorboard_callback:
                     if not os.path.exists(tensorboard_log_dir):
                         os.mkdir(tensorboard_log_dir)
                     new_log_dir = os.path.join(
-                        tensorboard_log_dir, f'model_{idx}_fold_{fold}')
+                        tensorboard_log_dir, f'model_{idx}_fold_{fold}'
+                    )
                     os.mkdir(new_log_dir)
                     tensorboard_callback.log_dir = new_log_dir
 
-                model.fit(
-                    train_dataset,
-                    validation_data=val_dataset,
-                    **kwargs,
-                )
+                model.fit(train_dataset, validation_data=val_dataset, **kwargs)
 
                 if len(model.metrics) > 1:
-                    val_score = model.evaluate(
-                        val_dataset,
-                        verbose=0
-                    )[-1]
+                    val_score = model.evaluate(val_dataset, verbose=0)[-1]
                 else:
-                    val_score = model.evaluate(
-                        val_dataset,
-                        verbose=0
-                    )
+                    val_score = model.evaluate(val_dataset, verbose=0)
                 val_scores[fold] = val_score
 
             self.results_["val_scores"].append(val_scores)
@@ -140,7 +129,7 @@ class BaseSearchCV(metaclass=ABCMeta):
         self.results_["best_score"] = self.results_["val_scores"][best_run_idx]
         self.results_["best_params"] = self.results_["params"][best_run_idx]
 
-    def summary(self) -> None:
+    def summary(self) -> str:
         """Prints the summary of the search to the console.
 
         Assuming the *RandomSearch* had n iterations or the
@@ -155,19 +144,33 @@ class BaseSearchCV(metaclass=ABCMeta):
             Idx: n-1 - Score: ``float`` using params: ``dict``
             --------------------------------------------------
         ```
+
+        Returns:
+            Full string of the summary that was printed.
         """
-        best_params_str = (f"Best score: {self.results_['best_score']} "
-                           f"using params: {self.results_['best_params']}")
+        best_params_str = (
+            f"Best score: {self.results_['best_score']} "
+            f"using params: {self.results_['best_params']}"
+        )
         dashed_line = "".join(map(lambda x: "-", best_params_str))
-        print(f"\n{dashed_line}\n{best_params_str}\n{dashed_line}")
+
+        current_line = f"\n{dashed_line}\n{best_params_str}\n{dashed_line}"
+        results_str = current_line
+        print(current_line)
 
         scores = self.results_["val_scores"]
         params = self.results_["params"]
 
         for idx, (score, param) in enumerate(zip(scores, params)):
-            print(f"Idx: {idx} - Score: {score} with param: {param}")
+            current_line = f"Idx: {idx} - Score: {score} with param: {param}"
+            results_str += current_line
+            print(current_line)
 
-        print(f"{dashed_line}\n")
+        current_line = f"{dashed_line}\n"
+        results_str += current_line
+        print(current_line)
+
+        return results_str
 
 
 class GridSearchCV(BaseSearchCV):
@@ -177,13 +180,29 @@ class GridSearchCV(BaseSearchCV):
         param_grid: Mapping[str, Iterable],
         n_folds: int = 3,
         verbose: int = 0,
-        **kwargs: Any
+        **kwargs: Any,
     ) -> None:
-        """GridSearch for a given parameter grid.
+        """GridSearchCV for a given parameter grid.
+
+        The grid search iterates over all combinations of the param_grid
+        dictionary, which defines the hyperparameter values for a key that
+        is a parameter name of the model_fn.
+        For example, if the model_fn has the parameter "num_units" a dictionary
+        could look like this:
+
+        ``` python
+            def model_fn(num_units: int):
+                pass
+
+            param_distributions = {"num_units": [10, 20 ,30]}
+        ```
+
+        Note: Inside the model_fn it is expected that the model is compiled.
+
+        The grid search is evaluated by:
+        - The validation loss value, if no metrics are passed to model.compile()
+        - The validation score of the last defined metric in model.compile()
 
-        The grid search is evaluated by the either the validation loss value,
-        if no metrics are passed to the compile function, or the
-        validation score of the last defined metric is used.
         ``` python
             model.compile(loss="mse", metrics=["mse", "mae"])
         ```
@@ -195,25 +214,18 @@ class GridSearchCV(BaseSearchCV):
             model_fn (Callable[..., tf.keras.models.Model]): Function that
                 builds and compiles a tf.keras.models.Model object.
             param_grid (Mapping[str, Iterable]): Dict of str, iterable
-                hyperparameter, where the str is the parameter name of the.
+            hyperparameter, where the str is the parameter name of the.
             n_folds (int): How many folds. Defaults to 3.
             verbose (int): Whether to show information in terminal.
                 Defaults to 0.
             kwargs (Any): Keyword arguments for the model_fn function.
         """
         super().__init__(
-            model_fn=model_fn,
-            n_folds=n_folds,
-            verbose=verbose,
-            **kwargs
+            model_fn=model_fn, n_folds=n_folds, verbose=verbose, **kwargs
         )
         self.param_grid = ParameterGrid(param_grid)
 
-    def fit(
-        self,
-        dataset: tf.data.Dataset,
-        **kwargs: Any
-    ) -> None:
+    def fit(self, dataset: tf.data.Dataset, **kwargs: Any) -> None:
         """Runs the exhaustive grid search over the parameter grid.
 
         Args:
@@ -222,9 +234,7 @@ class GridSearchCV(BaseSearchCV):
                 tf.keras.models.Model or tf.keras.models.Sequential model.
         """
         super()._run_search(
-            dataset=dataset,
-            parameter_obj=self.param_grid,
-            **kwargs
+            dataset=dataset, parameter_obj=self.param_grid, **kwargs
         )
 
 
@@ -236,18 +246,34 @@ class RandomSearchCV(BaseSearchCV):
         n_iter: int = 10,
         n_folds: int = 3,
         verbose: int = 0,
-        **kwargs: Any
+        **kwargs: Any,
     ) -> None:
-        """RandomSearch for a given parameter distribution.
+        """RandomSearchCV for a given parameter distribution.
+
+        The random search randomly iterates over the param_distributions
+        dictionary, which defines the hyperparameter value range for a key that
+        is a parameter name of the model_fn.
+        For example, if the model_fn has the parameter "num_units" a dictionary
+        could look like this:
+
+        ``` python
+            def model_fn(num_units: int):
+                pass
+
+            param_distributions = {"num_units": [10, 20 ,30]}
+        ```
+
+        Note: Inside the model_fn it is expected that the model is compiled.
+
+        The random search is evaluated by:
+        - The validation loss value, if no metrics are passed to model.compile()
+        - The validation score of the last defined metric in model.compile()
 
-        The random search is evaluated by the either the validation loss value,
-        if no metrics are passed to the compile function, or the
-        validation score of the last defined metric is used.
         ``` python
             model.compile(loss="mse", metrics=["mse", "mae"])
         ```
 
-        This would sort the random search combinations based on the validation
+        This would sort the grid search combinations based on the validation
         mae score.
 
         Args:
@@ -262,23 +288,15 @@ class RandomSearchCV(BaseSearchCV):
             kwargs (Any): Keyword arguments for the model_fn function.
         """
         super().__init__(
-            model_fn=model_fn,
-            n_folds=n_folds,
-            verbose=verbose,
-            **kwargs
+            model_fn=model_fn, n_folds=n_folds, verbose=verbose, **kwargs
         )
         self.param_distributions = param_distributions
         self.n_iter = n_iter
         self.random_sampler = ParameterSampler(
-            self.param_distributions,
-            n_iter=self.n_iter
+            self.param_distributions, n_iter=self.n_iter
         )
 
-    def fit(
-        self,
-        dataset: tf.data.Dataset,
-        **kwargs: Any
-    ) -> None:
+    def fit(self, dataset: tf.data.Dataset, **kwargs: Any) -> None:
         """Runs the random search over the parameter distributions.
 
         Args:
@@ -287,7 +305,5 @@ class RandomSearchCV(BaseSearchCV):
                 tf.keras.models.Model or tf.keras.models.Sequential model.
         """
         super()._run_search(
-            dataset=dataset,
-            parameter_obj=self.random_sampler,
-            **kwargs
+            dataset=dataset, parameter_obj=self.random_sampler, **kwargs
         )
